summaryrefslogtreecommitdiff
path: root/ace/Select_Reactor_T.h
diff options
context:
space:
mode:
authorschmidt <douglascraigschmidt@users.noreply.github.com>1999-08-18 02:02:27 +0000
committerschmidt <douglascraigschmidt@users.noreply.github.com>1999-08-18 02:02:27 +0000
commitf593e1cd3d92bd697776af6773e614cd404aeb32 (patch)
tree1134f3b4450a94e87c9f485fa77213ff8a1b2905 /ace/Select_Reactor_T.h
parent3e94ae019f94e693db519bfa4fbea86242f2bae6 (diff)
downloadATCD-f593e1cd3d92bd697776af6773e614cd404aeb32.tar.gz
ChangeLogTag:Tue Aug 17 20:02:55 1999 Douglas C. Schmidt <schmidt@tango.cs.wustl.edu>
Diffstat (limited to 'ace/Select_Reactor_T.h')
-rw-r--r--ace/Select_Reactor_T.h33
1 files changed, 21 insertions, 12 deletions
diff --git a/ace/Select_Reactor_T.h b/ace/Select_Reactor_T.h
index 9763762d3a9..76be6e62a13 100644
--- a/ace/Select_Reactor_T.h
+++ b/ace/Select_Reactor_T.h
@@ -333,21 +333,30 @@ public:
// = Timer management.
virtual long schedule_timer (ACE_Event_Handler *,
const void *arg,
- const ACE_Time_Value &delta_time,
+ const ACE_Time_Value &delta,
const ACE_Time_Value &interval = ACE_Time_Value::zero);
- // Schedule an <event_handler> that will expire after <delta_time>
- // amount of time. If it expires then <arg> is passed in as the
+ // Schedule an <event_handler> that will expire after <delta> amount
+ // of time, which is specified as relative time to the current
+ // <gettimeofday>. If it expires then <arg> is passed in as the
// value to the <event_handler>'s <handle_timeout> callback method.
// If <interval> is != to <ACE_Time_Value::zero> then it is used to
- // reschedule the <event_handler> automatically. This method
- // returns a <timer_id> that uniquely identifies the <event_handler>
- // in an internal list. This <timer_id> can be used to cancel an
- // <event_handler> before it expires. The cancellation ensures that
- // <timer_ids> are unique up to values of greater than 2 billion
- // timers. As long as timers don't stay around longer than this
- // there should be no problems with accidentally deleting the wrong
- // timer. Returns -1 on failure (which is guaranteed never to be a
- // valid <timer_id>.
+ // reschedule the <event_handler> automatically, which is also
+ // specified using relative time. This method returns a <timer_id>
+ // that uniquely identifies the <event_handler> in an internal list.
+ // This <timer_id> can be used to cancel an <event_handler> before
+ // it expires. The cancellation ensures that <timer_ids> are unique
+ // up to values of greater than 2 billion timers. As long as timers
+ // don't stay around longer than this there should be no problems
+ // with accidentally deleting the wrong timer. Returns -1 on
+ // failure (which is guaranteed never to be a valid <timer_id>.
+
+ virtual int reset_timer_interval (const long timer_id,
+ const ACE_Time_Value &interval);
+ // Resets the interval of the timer represented by <timer_id> to
+ // <interval>, which is specified in relative time to the current
+ // <gettimeofday>. If <interval> is equal to
+ // <ACE_Time_Value::zero>, the timer will become a non-rescheduling
+ // timer. Returns 0 if successful, -1 if not.
virtual int cancel_timer (ACE_Event_Handler *event_handler,
int dont_call_handle_close = 1);